==> crm-commom-vo-1.1.9.25.release.jar: com/biz/crm/nebular/sfa/worksignrule/SfaWorkSignRuleVo.java <==
package com.biz.crm.nebular.sfa.worksignrule;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;

/**
 * 考勤规则查询对象
 *
 * @author liuhongming
 * @date 2020-09-16 14:50:03
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "SfaWorkSignRuleQueryReqVo", description = "考勤规则查询对象")
public class SfaWorkSignRuleVo extends CrmExtVo {

    @ApiModelProperty("id集合;id集合")
    private List<String> ids;

    @ApiModelProperty("规则编码;规则编码")
    @SaturnColumn(description = "考勤规则-规则编码")
    private String ruleCode;

    @ApiModelProperty("规则名称;规则名称")
    @SaturnColumn(description = "考勤规则-规则名称")
    private String ruleName;

    @ApiModelProperty("规则类型;规则类型(STATIC:固定时间上下班规则/FREE_TIME:自由时间上下班规则)")
    @SaturnColumn(description = "考勤规则-规则类型(STATIC:固定时间上下班规则/FREE_TIME:自由时间上下班规则)")
    private String ruleType;

    @ApiModelProperty("规则类型名称")
    @CrmDict(typeCode = "commutingType",dictCodeField = "ruleType")
    private String ruleTypeName;

    @ApiModelProperty("电子围栏;电子围栏(NONE:无电子围栏/OUT_SIGN_EX:允许范围外打卡，地点记录为异常/OUT_SIGN_OK:允许范围外打卡，地点记录为正常/NO_OUT_SIGN:不允许范围外打卡)")
    @SaturnColumn(description = "考勤规则-电子围栏(NONE:无电子围栏/OUT_SIGN_EX:允许范围外打卡，地点记录为异常/OUT_SIGN_OK:允许范围外打卡，地点记录为正常/NO_OUT_SIGN:不允许范围外打卡)")
    private String electronFence;

    @ApiModelProperty("工作日;(1:星期一;2:星期二;3:星期三;4:星期四;5:星期五;6:星期六;7:星期日)")
    @SaturnColumn(description = "考勤规则-(1:星期一;2:星期二;3:星期三;4:星期四;5:星期五;6:星期六;7:星期日)")
    private String workingDay;

    @ApiModelProperty("工作日调整(Y:工作日调整申请时是否遵循此规则)")
    @SaturnColumn(description = "非工作日是否对打卡进行时间范围规则限制（Y/N 默认N）")
    private String nonWorkingDaySignAstrict;

    @ApiModelProperty("节假日;节假日(Y：同步中国节假日节假日期间不用打卡)")
    @SaturnColumn(description = "考勤规则-节假日(Y：同步中国节假日节假日期间不用打卡)")
    private String holidayWhether;

    @ApiModelProperty("拍照打卡;拍照打卡(Y:员工打卡时必须拍照)")
    @SaturnColumn(description = "考勤规则-拍照打卡(Y:员工打卡时必须拍照)")
    private String wsrPhotograph;

    @ApiModelProperty("下班打卡限制;(NO_SIGN:下班不需要打卡;GOTO_WORK_REQUIRED:下班需要打卡，且必须打上班卡才能打下班卡;GOTO_WORK_NO_REQUIRED:下班需要打卡，无需打上班卡，就能打下班卡)")
    @SaturnColumn(description = "下班打卡限制;(NO_SIGN:下班不需要打卡;GOTO_WORK_REQUIRED:下班需要打卡，且必须打上班卡才能打下班卡;GOTO_WORK_NO_REQUIRED:下班需要打卡，无需打上班卡，就能打下班卡)")
    private String gooffWorkSignAstrict;



}

==> crm-commom-vo-1.1.9.45.release.jar: com/biz/crm/nebular/sfa/worksignrule/SfaWorkSignRuleVo.java <==
package com.biz.crm.nebular.sfa.worksignrule;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmExtVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;

/**
 * 考勤规则查询对象
 *
 * @author liuhongming
 * @date 2020-09-16 14:50:03
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "SfaWorkSignRuleQueryReqVo", description = "考勤规则查询对象")
public class SfaWorkSignRuleVo extends CrmExtVo {

    @ApiModelProperty("id集合;id集合")
    private List<String> ids;

    @ApiModelProperty("规则编码;规则编码")
    @SaturnColumn(description = "考勤规则-规则编码")
    private String ruleCode;

    @ApiModelProperty("规则名称;规则名称")
    @SaturnColumn(description = "考勤规则-规则名称")
    private String ruleName;

    @ApiModelProperty("规则类型;规则类型(STATIC:固定时间上下班规则/FREE_TIME:自由时间上下班规则)")
    @SaturnColumn(description = "考勤规则-规则类型(STATIC:固定时间上下班规则/FREE_TIME:自由时间上下班规则)")
    private String ruleType;

    @ApiModelProperty("规则类型名称")
    @CrmDict(typeCode = "commutingType",dictCodeField = "ruleType")
    private String ruleTypeName;

    @ApiModelProperty("电子围栏;电子围栏(NONE:无电子围栏/OUT_SIGN_EX:允许范围外打卡，地点记录为异常/OUT_SIGN_OK:允许范围外打卡，地点记录为正常/NO_OUT_SIGN:不允许范围外打卡)")
    @SaturnColumn(description = "考勤规则-电子围栏(NONE:无电子围栏/OUT_SIGN_EX:允许范围外打卡，地点记录为异常/OUT_SIGN_OK:允许范围外打卡，地点记录为正常/NO_OUT_SIGN:不允许范围外打卡)")
    private String electronFence;

    @ApiModelProperty("工作日;(1:星期一;2:星期二;3:星期三;4:星期四;5:星期五;6:星期六;7:星期日)")
    @SaturnColumn(description = "考勤规则-(1:星期一;2:星期二;3:星期三;4:星期四;5:星期五;6:星期六;7:星期日)")
    private String workingDay;

    @ApiModelProperty("工作日调整申请时是否遵循此规则(前端气泡)（Y/N 默认N）")
    @SaturnColumn(description = "工作日调整申请时是否遵循此规则(前端气泡)（Y/N 默认N）")
    private String nonWorkingDaySignAstrict;

    @ApiModelProperty("节假日;节假日(Y：同步中国节假日节假日期间不用打卡)")
    @SaturnColumn(description = "考勤规则-节假日(Y：同步中国节假日节假日期间不用打卡)")
    private String holidayWhether;

    @ApiModelProperty("拍照打卡;拍照打卡(Y:员工打卡时必须拍照)")
    @SaturnColumn(description = "考勤规则-拍照打卡(Y:员工打卡时必须拍照)")
    private String wsrPhotograph;

    @ApiModelProperty("下班打卡限制;(NO_SIGN:下班不需要打卡;GOTO_WORK_REQUIRED:下班需要打卡，且必须打上班卡才能打下班卡;GOTO_WORK_NO_REQUIRED:下班需要打卡，无需打上班卡，就能打下班卡)")
    @SaturnColumn(description = "下班打卡限制;(NO_SIGN:下班不需要打卡;GOTO_WORK_REQUIRED:下班需要打卡，且必须打上班卡才能打下班卡;GOTO_WORK_NO_REQUIRED:下班需要打卡，无需打上班卡，就能打下班卡)")
    private String gooffWorkSignAstrict;



}
